-- -----------------------------------------------------------------------------
--       TABLE : MATERIAU
-- -----------------------------------------------------------------------------

CREATE TABLE MATERIAU
   (
    NUMMATERIAU INTEGER  NOT NULL,
    NOMMATERIAU CHAR(32)  NULL
,   CONSTRAINT PK_MATERIAU PRIMARY KEY (NUMMATERIAU)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : APTITUDE
-- -----------------------------------------------------------------------------

CREATE TABLE APTITUDE
   (
    NUMAPTITUDE INTEGER  NOT NULL,
    NUMCLASSE INTEGER  NOT NULL,
    NOMAPTITUDE CHAR(32)  NULL,
    NIVEAUREQUIS CHAR(32)  NULL
,   CONSTRAINT PK_APTITUDE PRIMARY KEY (NUMAPTITUDE)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE APTITUDE
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_APTITUDE_CLASSE
     ON APTITUDE (NUMCLASSE ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : TYPEPERSONNAGE
-- -----------------------------------------------------------------------------

CREATE TABLE TYPEPERSONNAGE
   (
    NUMTYPEPERSONNAGE INTEGER  NOT NULL,
    NOMTYPEPERSONNAGE CHAR(32)  NULL,
    ROYAUMETYPEPERSONNAGE CHAR(32)  NULL
,   CONSTRAINT PK_TYPEPERSONNAGE PRIMARY KEY (NUMTYPEPERSONNAGE)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : MONTURE
-- -----------------------------------------------------------------------------

CREATE TABLE MONTURE
   (
    NUMMONTURE INTEGER  NOT NULL,
    NUMPERSONNAGE INTEGER  NOT NULL,
    NUMTYPEMONTURE INTEGER  NOT NULL,
    COULEUR CHAR(32)  NULL
,   CONSTRAINT PK_MONTURE PRIMARY KEY (NUMMONTURE)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE MONTURE
-- -----------------------------------------------------------------------------

CREATE UNIQUE INDEX I_FK_MONTURE_PERSONNAGE
     ON MONTURE (NUMPERSONNAGE ASC)
    ;

CREATE  INDEX I_FK_MONTURE_TYPEMONTURE
     ON MONTURE (NUMTYPEMONTURE ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : TYPEEQUIPEMENT
-- -----------------------------------------------------------------------------

CREATE TABLE TYPEEQUIPEMENT
   (
    NUMTYPEEQUIPEMENT INTEGER  NOT NULL,
    NUMMTIER INTEGER  NOT NULL,
    NOMTYPEEQUIPEMENT CHAR(32)  NULL
,   CONSTRAINT PK_TYPEEQUIPEMENT PRIMARY KEY (NUMTYPEEQUIPEMENT)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE TYPEEQUIPEMENT
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_TYPEEQUIPEMENT_METIER
     ON TYPEEQUIPEMENT (NUMMTIER ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : TYPEMONTURE
-- -----------------------------------------------------------------------------

CREATE TABLE TYPEMONTURE
   (
    NUMTYPEMONTURE INTEGER  NOT NULL,
    NOMTYPEMONTURE CHAR(32)  NULL
,   CONSTRAINT PK_TYPEMONTURE PRIMARY KEY (NUMTYPEMONTURE)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : METIER
-- -----------------------------------------------------------------------------

CREATE TABLE METIER
   (
    NUMMTIER INTEGER  NOT NULL,
    NOMMTIER CHAR(32)  NULL
,   CONSTRAINT PK_METIER PRIMARY KEY (NUMMTIER)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : ARMURE
-- -----------------------------------------------------------------------------

CREATE TABLE ARMURE
   (
    NUMARMURE INTEGER  NOT NULL,
    NUMPERSONNAGE INTEGER  NOT NULL,
    NUMTYPEEQUIPEMENT INTEGER  NOT NULL
,   CONSTRAINT PK_ARMURE PRIMARY KEY (NUMARMURE)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE ARMURE
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_ARMURE_PERSONNAGE
     ON ARMURE (NUMPERSONNAGE ASC)
    ;

CREATE  INDEX I_FK_ARMURE_TYPEEQUIPEMENT
     ON ARMURE (NUMTYPEEQUIPEMENT ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : CLASSE
-- -----------------------------------------------------------------------------

CREATE TABLE CLASSE
   (
    NUMCLASSE INTEGER  NOT NULL,
    NOMCLASSE CHAR(32)  NULL
,   CONSTRAINT PK_CLASSE PRIMARY KEY (NUMCLASSE)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : PERSONNAGE
-- -----------------------------------------------------------------------------

CREATE TABLE PERSONNAGE
   (
    NUMPERSONNAGE INTEGER  NOT NULL,
    NUMCLASSE INTEGER  NOT NULL,
    NUMTYPEPERSONNAGE INTEGER  NOT NULL,
    NUMMTIER INTEGER  NOT NULL,
    NUMCOMPTEUTILISATEUR INTEGER  NOT NULL,
    NOMPERSONNAGE CHAR(32)  NULL,
    NIVEAUPERSONNAGE INTEGER  NULL,
    SEXEPERSONNAGE CHAR(1)  NULL
,   CONSTRAINT PK_PERSONNAGE PRIMARY KEY (NUMPERSONNAGE)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE PERSONNAGE
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_PERSONNAGE_CLASSE
     ON PERSONNAGE (NUMCLASSE ASC)
    ;

CREATE  INDEX I_FK_PERSONNAGE_TYPEPERSONNAGE
     ON PERSONNAGE (NUMTYPEPERSONNAGE ASC)
    ;

CREATE  INDEX I_FK_PERSONNAGE_METIER
     ON PERSONNAGE (NUMMTIER ASC)
    ;

CREATE  INDEX I_FK_PERSONNAGE_COMPTEUTILISAT
     ON PERSONNAGE (NUMCOMPTEUTILISATEUR ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : COMPTEUTILISATEUR
-- -----------------------------------------------------------------------------

CREATE TABLE COMPTEUTILISATEUR
   (
    NUMCOMPTEUTILISATEUR INTEGER  NOT NULL,
    DATEINSCRIPTION DATE  NULL,
    DERNIREDATECONNEXION DATE  NULL,
    NBHEUREJEU INTEGER  NULL
,   CONSTRAINT PK_COMPTEUTILISATEUR PRIMARY KEY (NUMCOMPTEUTILISATEUR)  
   ) ;

-- -----------------------------------------------------------------------------
--       TABLE : ARME
-- -----------------------------------------------------------------------------

CREATE TABLE ARME
   (
    NUMARME INTEGER  NOT NULL,
    NUMTYPEEQUIPEMENT INTEGER  NOT NULL,
    NUMPERSONNAGE INTEGER  NOT NULL
,   CONSTRAINT PK_ARME PRIMARY KEY (NUMARME)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE ARME
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_ARME_TYPEEQUIPEMENT
     ON ARME (NUMTYPEEQUIPEMENT ASC)
    ;

CREATE  INDEX I_FK_ARME_PERSONNAGE
     ON ARME (NUMPERSONNAGE ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : PLANFABRICATION
-- -----------------------------------------------------------------------------

CREATE TABLE PLANFABRICATION
   (
    NUMTYPEEQUIPEMENT INTEGER  NOT NULL,
    NUMMATERIAU INTEGER  NOT NULL,
    QTENCESSAIRE INTEGER  NULL
,   CONSTRAINT PK_PLANFABRICATION PRIMARY KEY (NUMTYPEEQUIPEMENT, NUMMATERIAU)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE PLANFABRICATION
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_PLANFABRICATION_TYPEEQUIP
     ON PLANFABRICATION (NUMTYPEEQUIPEMENT ASC)
    ;

CREATE  INDEX I_FK_PLANFABRICATION_MATERIAU
     ON PLANFABRICATION (NUMMATERIAU ASC)
    ;

-- -----------------------------------------------------------------------------
--       TABLE : SACMATERIAUX
-- -----------------------------------------------------------------------------

CREATE TABLE SACMATERIAUX
   (
    NUMPERSONNAGE INTEGER  NOT NULL,
    NUMMATERIAU INTEGER  NOT NULL,
    QTEMATRIAUXPORTS INTEGER  NULL
,   CONSTRAINT PK_SACMATERIAUX PRIMARY KEY (NUMPERSONNAGE, NUMMATERIAU)  
   ) ;

-- -----------------------------------------------------------------------------
--       INDEX DE LA TABLE SACMATERIAUX
-- -----------------------------------------------------------------------------

CREATE  INDEX I_FK_SACMATERIAUX_PERSONNAGE
     ON SACMATERIAUX (NUMPERSONNAGE ASC)
    ;

CREATE  INDEX I_FK_SACMATERIAUX_MATERIAU
     ON SACMATERIAUX (NUMMATERIAU ASC)
    ;


-- -----------------------------------------------------------------------------
--       CREATION DES REFERENCES DE TABLE
-- -----------------------------------------------------------------------------


ALTER TABLE APTITUDE ADD (
     CONSTRAINT FK_APTITUDE_CLASSE
          FOREIGN KEY (NUMCLASSE)
               REFERENCES CLASSE (NUMCLASSE))   ;

ALTER TABLE MONTURE ADD (
     CONSTRAINT FK_MONTURE_PERSONNAGE
          FOREIGN KEY (NUMPERSONNAGE)
               REFERENCES PERSONNAGE (NUMPERSONNAGE))   ;

ALTER TABLE MONTURE ADD (
     CONSTRAINT FK_MONTURE_TYPEMONTURE
          FOREIGN KEY (NUMTYPEMONTURE)
               REFERENCES TYPEMONTURE (NUMTYPEMONTURE))   ;

ALTER TABLE TYPEEQUIPEMENT ADD (
     CONSTRAINT FK_TYPEEQUIPEMENT_METIER
          FOREIGN KEY (NUMMTIER)
               REFERENCES METIER (NUMMTIER))   ;

ALTER TABLE ARMURE ADD (
     CONSTRAINT FK_ARMURE_PERSONNAGE
          FOREIGN KEY (NUMPERSONNAGE)
               REFERENCES PERSONNAGE (NUMPERSONNAGE))   ;

ALTER TABLE ARMURE ADD (
     CONSTRAINT FK_ARMURE_TYPEEQUIPEMENT
          FOREIGN KEY (NUMTYPEEQUIPEMENT)
               REFERENCES TYPEEQUIPEMENT (NUMTYPEEQUIPEMENT))   ;

ALTER TABLE PERSONNAGE ADD (
     CONSTRAINT FK_PERSONNAGE_CLASSE
          FOREIGN KEY (NUMCLASSE)
               REFERENCES CLASSE (NUMCLASSE))   ;

ALTER TABLE PERSONNAGE ADD (
     CONSTRAINT FK_PERSONNAGE_TYPEPERSONNAGE
          FOREIGN KEY (NUMTYPEPERSONNAGE)
               REFERENCES TYPEPERSONNAGE (NUMTYPEPERSONNAGE))   ;

ALTER TABLE PERSONNAGE ADD (
     CONSTRAINT FK_PERSONNAGE_METIER
          FOREIGN KEY (NUMMTIER)
               REFERENCES METIER (NUMMTIER))   ;

ALTER TABLE PERSONNAGE ADD (
     CONSTRAINT FK_PERSONNAGE_COMPTEUTILISATEU
          FOREIGN KEY (NUMCOMPTEUTILISATEUR)
               REFERENCES COMPTEUTILISATEUR (NUMCOMPTEUTILISATEUR))   ;

ALTER TABLE ARME ADD (
     CONSTRAINT FK_ARME_TYPEEQUIPEMENT
          FOREIGN KEY (NUMTYPEEQUIPEMENT)
               REFERENCES TYPEEQUIPEMENT (NUMTYPEEQUIPEMENT))   ;

ALTER TABLE ARME ADD (
     CONSTRAINT FK_ARME_PERSONNAGE
          FOREIGN KEY (NUMPERSONNAGE)
               REFERENCES PERSONNAGE (NUMPERSONNAGE))   ;

ALTER TABLE PLANFABRICATION ADD (
     CONSTRAINT FK_PLANFABRICATION_TYPEEQUIPEM
          FOREIGN KEY (NUMTYPEEQUIPEMENT)
               REFERENCES TYPEEQUIPEMENT (NUMTYPEEQUIPEMENT))   ;

ALTER TABLE PLANFABRICATION ADD (
     CONSTRAINT FK_PLANFABRICATION_MATERIAU
          FOREIGN KEY (NUMMATERIAU)
               REFERENCES MATERIAU (NUMMATERIAU))   ;

ALTER TABLE SACMATERIAUX ADD (
     CONSTRAINT FK_SACMATERIAUX_PERSONNAGE
          FOREIGN KEY (NUMPERSONNAGE)
               REFERENCES PERSONNAGE (NUMPERSONNAGE))   ;

ALTER TABLE SACMATERIAUX ADD (
     CONSTRAINT FK_SACMATERIAUX_MATERIAU
          FOREIGN KEY (NUMMATERIAU)
               REFERENCES MATERIAU (NUMMATERIAU))   ;


-- -----------------------------------------------------------------------------
--                FIN DE GENERATION
-- -----------------------------------------------------------------------------